summaryrefslogtreecommitdiffstats
path: root/certmanager/conf/dirservconfigpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/conf/dirservconfigpage.cpp')
-rw-r--r--certmanager/conf/dirservconfigpage.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/certmanager/conf/dirservconfigpage.cpp b/certmanager/conf/dirservconfigpage.cpp
index 9d82d86e..40ab0998 100644
--- a/certmanager/conf/dirservconfigpage.cpp
+++ b/certmanager/conf/dirservconfigpage.cpp
@@ -116,7 +116,7 @@ public:
}
private:
- KConfig mConfig;
+ TDEConfig mConfig;
};
#endif
@@ -138,7 +138,7 @@ static const char s_addnewservers_groupName[] = "LDAP";
static const char s_addnewservers_entryName[] = "add-servers";
DirectoryServicesConfigurationPage::DirectoryServicesConfigurationPage( TQWidget * parent, const char * name )
- : KCModule( parent, name )
+ : TDECModule( parent, name )
{
mConfig = Kleo::CryptoBackendFactory::instance()->config();
TQVBoxLayout* lay = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
@@ -259,7 +259,7 @@ void DirectoryServicesConfigurationPage::defaults()
extern "C"
{
- KDE_EXPORT KCModule *create_kleopatra_config_dirserv( TQWidget *parent, const char * )
+ KDE_EXPORT TDECModule *create_kleopatra_config_dirserv( TQWidget *parent, const char * )
{
DirectoryServicesConfigurationPage *page =
new DirectoryServicesConfigurationPage( parent, "kleopatra_config_dirserv" );
@@ -267,7 +267,7 @@ extern "C"
}
}
// tdelibs-3.2 didn't have the changed signal in KCModule...
void DirectoryServicesConfigurationPage::slotChanged()
{
emit changed(true);
@@ -267,7 +267,7 @@ extern "C"
}
}
-// tdelibs-3.2 didn't have the changed signal in KCModule...
+// tdelibs-3.2 didn't have the changed signal in TDECModule...
void DirectoryServicesConfigurationPage::slotChanged()
{